@@ -287,6 +287,9 @@ INVALIDPARAMETERVALUE_INSTANCENOTMATCHASSOCIATEENI = 'InvalidParameterValue.Inst
 # 网络计费模式没有更改。
 INVALIDPARAMETERVALUE_INTERNETCHARGETYPENOTCHANGED = 'InvalidParameterValue.InternetChargeTypeNotChanged'
 
+# 参数非法
+INVALIDPARAMETERVALUE_INVALID = 'InvalidParameterValue.Invalid'
+
 # 无效的带宽包计费方式。
 INVALIDPARAMETERVALUE_INVALIDBANDWIDTHPACKAGECHARGETYPE = 'InvalidParameterValue.InvalidBandwidthPackageChargeType'
 
@@ -878,6 +881,12 @@ UNSUPPORTEDOPERATION_CCNHASFLOWLOG = 'UnsupportedOperation.CcnHasFlowLog'
 # CCN实例所属账号未通过联通审批。
 UNSUPPORTEDOPERATION_CCNINSTANCEACCOUNTNOTAPPROVEDBYUNICOM = 'UnsupportedOperation.CcnInstanceAccountNotApprovedByUnicom'
 
+# 云联网关联实例绑定了策略路由下一跳，不允许解关联，需要先解绑策略路由下一跳
+UNSUPPORTEDOPERATION_CCNINSTANCEHASBOUNDPOLICYROUTENEXTHOPNOTALLOWEDDETACH = 'UnsupportedOperation.CcnInstanceHasBoundPolicyRouteNextHopNotAllowedDetach'
+
+# 云联网关联实例绑定了策略路由规则，不允许解关联，需要先解绑策略路由规则
+UNSUPPORTEDOPERATION_CCNINSTANCEHASBOUNDPOLICYROUTERULENOTALLOWEDDETACH = 'UnsupportedOperation.CcnInstanceHasBoundPolicyRouteRuleNotAllowedDetach'
+
 # 云联网开启ipv6不支持创建多路由表
 UNSUPPORTEDOPERATION_CCNIPV6NOTSUPPORTMULTIPLEROUTETABLE = 'UnsupportedOperation.CcnIpv6NotSupportMultipleRouteTable'
 
@@ -1196,6 +1205,9 @@ UNSUPPORTEDOPERATION_NOTSUPPORTDELETEVPCBMPEER = 'UnsupportedOperation.NotSuppor
 # 默认路由表，不支持修改。
 UNSUPPORTEDOPERATION_NOTSUPPORTMODIFYDEFAULTCCNROUTETABLE = 'UnsupportedOperation.NotSupportModifyDefaultCcnRouteTable'
 
+# 不支持的自定义路由类型。
+UNSUPPORTEDOPERATION_NOTSUPPORTROUTETYPE = 'UnsupportedOperation.NotSupportRouteType'
+
 # 不支持编辑相同的实例和源地址。
 UNSUPPORTEDOPERATION_NOTSUPPORTSAMECCNINSTANCEANDSOURCEADDRESS = 'UnsupportedOperation.NotSupportSameCcnInstanceAndSourceAddress'
 
